%define upstream_name llvmlite

Name:           python-%{upstream_name}
Version:        0.35.0
Release:        %mkrel 1
Summary:        A lightweight LLVM python binding for writing JIT compilers
License:        BSD
Group:          Development/Python
Url:            http://llvmlite.pydata.org/en/latest/
Source:         https://github.com/numba/llvmlite/archive/v%{version}%{?beta}/llvmlite-%{version}%{?beta}.tar.gz
BuildRequires:  llvm-devel < 11

%description
The old llvmpy binding exposes a lot of LLVM APIs but the mapping of C++-style
memory management to Python is error prone. Numba and many JIT compilers do not
need a full LLVM API. Only the IR builder, optimizer, and JIT compiler APIs are
necessary.

llvmlite is a project originally tailored for Numba’s needs, using the
following approach:
- A small C wrapper around the parts of the LLVM C++ API we need that are not
  already exposed by the LLVM C API.
- A ctypes Python wrapper around the C API.
- A pure Python implementation of the subset of the LLVM IR builder that we
  need for Numba.

%package -n python3-%{upstream_name}
Summary:        A lightweight LLVM python binding for writing JIT compilers
Group:          Development/Python
License:        BSD
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3-numpy-devel

%description -n python3-%{upstream_name}
The old llvmpy binding exposes a lot of LLVM APIs but the mapping of C++-style
memory management to Python is error prone. Numba and many JIT compilers do not
need a full LLVM API. Only the IR builder, optimizer, and JIT compiler APIs are
necessary.

llvmlite is a project originally tailored for Numba’s needs, using the
following approach:
- A small C wrapper around the parts of the LLVM C++ API we need that are not
  already exposed by the LLVM C API.
- A ctypes Python wrapper around the C API.
- A pure Python implementation of the subset of the LLVM IR builder that we
  need for Numba.

%prep
%autosetup -p1 -n %{upstream_name}-%{version}%{?beta}

%build
# Fails building without -fPIC
export CXXFLAGS="%{optflags} -fPIC"
export LDFLAGS="%{ldflags} -fPIC"
export LLVM_CONFIG="%{_bindir}/llvm-config-10"
%py3_build

%install
%py3_install

%files -n python3-%{upstream_name}
%doc LICENSE README.rst
%{python3_sitearch}/llvmlite
%{python3_sitearch}/llvmlite*.egg-info


%changelog
* Tue Jan 26 2021 daviddavid <daviddavid> 0.35.0-1.mga8
+ Revision: 1673375
- new version: 0.35.0 (llvm 10 support)
+ tv <tv>
- rebuild for llvm-11

* Sat Apr 18 2020 guillomovitch <guillomovitch> 0.32.0-1.mga8
+ Revision: 1568799
- new version 0.32.0
- new version 0.30.0
+ tv <tv>
- fix build: llvm10 got rid of lvm::make_unique in favour of std::make_unique
- new release
- fix build with llvm 10
- rebuild with llvm 10
- patch 0: add llvm9.0 support
- final release
- drop python2 subpkg
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Sun May 26 2019 guillomovitch <guillomovitch> 0.29.0-1.rc1.1.mga7
+ Revision: 1399167
- new version 0.29.0rc1

* Wed May 15 2019 tv <tv> 0.29.0-0.20190512.1.mga7
+ Revision: 1397860
- fix build with llmv8.0 (newer git snapshot)
+ daviddavid <daviddavid>
- rebuild for new llvm/clang 8.0

* Fri Mar 22 2019 guillomovitch <guillomovitch> 0.28.0-1.mga7
+ Revision: 1379643
- imported package python-llvmlite

